======
Toston
======


.. image:: https://img.shields.io/pypi/v/toston.svg
        :target: https://pypi.python.org/pypi/toston

.. image:: https://img.shields.io/travis/joseamaita/toston.svg
        :target: https://travis-ci.org/joseamaita/toston

.. image:: https://readthedocs.org/projects/toston/badge/?version=latest
        :target: https://toston.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Toston generates a secret key with size variable (in bytes)

The idea behind this module is that you can take advantage of 
the `secrets` module to generate really secret and random keys to be 
implemented in your web applications.


* Free software: MIT license
* Documentation: https://toston.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
